/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalBiquad.h"
#include "HvControlCast.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvControlBinop.h"
#include "HvControlVar.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_H6vLgg9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MV5LLL1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0uMDkVNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HgM0N5Kk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AvVjakyH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_s7toOusK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H9onsVOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z5ihR74I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wvRaefjx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ytZ80B4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AKfP8c4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tF1MbIgU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TtcMOlx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HnbAYR7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WzhD11oa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LhPf6ynL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kbf7QNe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WFS280cJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JGYfKp6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oGKP0OxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gNn28FuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bT8wJgaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RH3qRHqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sotJsbBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GqwiPRvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TuJqe8DH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YY59L4Kc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X3wt0wyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nnd0zuIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lw2cp81p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ebklagCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RO9EHkPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gpBC7nYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WMemUAjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rppfDOyp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GMJkIXCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vwXng290_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M2jOesf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rSXpxM7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZLQxEma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_beDh3HoS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mOCbG0rP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6EkTqaVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_r21CRfKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z8SDR2sb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W3t3L0Vm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OumIJH8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wZ97c7Yq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FRj6d58f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u4oC2AAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6gRKN6NH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1uC7Xty8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jEoMSeOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l3JNgsVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sb0wBEqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hF2WXoYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SvgMn3A4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xUq3YXQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GTt0By0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ib25Gjtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uP8aoN0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ki4zh8tF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lPZwG58M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_910wGhLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6tdvLEH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EcKnk8Re_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sXi3TT7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eLgfc2O1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MZrM8EAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZsVImThV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DG7AGp2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2lIh3RpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_utBl0KZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vkDIu5tU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u8aBZHEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uuuPFwdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V2ggJQUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4lPVwzP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SdGUgDK9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_l56FawAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VS3yf615_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0Crj4dog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WLQ4tH13_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7EuKpCMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_01byo3fo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LvoU9bnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ejiFkkLp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rALyv4K3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6CIUOA37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_77BeKubZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HkJiQrQs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sTrNphHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tavRIZer_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9fauk4RI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gdLNt5Ht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jcvTpwud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GiS2du5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uB578oVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ep4zHCvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_teC1x0NZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_omlD7L8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_32E8hrnM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ls8TL4oV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OBbIyzbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iYDwc5ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tdgr2Umw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ey2MYqY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_J4UPt5gb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3zWFPu8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DQxqRSyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0IpyfSOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7agLf46Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLzkHUMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WEgyCkzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MUrzKMen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PySljEmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZoKNuS4E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hf7YCvui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j39p0EHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YV2cInC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ip2VllZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_efljQA6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zFhDpmZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w3XpGamq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lurXnupj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TuWwvntM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LVYG1mPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k5K74lHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_f7QpLzBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pFOtA1Sa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZwnxkRgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AU7rnRjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BYB464v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jz5KUuAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6WtOxkFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6iONfEjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kJTm3opz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oYbM7ONi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LxGnbmrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mXkCX2R2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eag34nUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Imq2OfJ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ayq4heK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bRjgC1BD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_00ztz0r6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MEAfNlHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RvdxxBuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gMiExA1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5WoHBmLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kb6frjjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1wPyxJJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1bwlJpGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hgzpbY01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HH7KHWp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MNNhawQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kq7n1p0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uId7lTnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xRa9Rhjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZnuSf4dM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rfq0Nz6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_byWrhKAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3aTZKv9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xMG6qOTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cewrW6yz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xagRozaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5vTfrWeg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ximKUoS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uSzAmenp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cKEbHHbb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W85ovcoM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aDFm7uQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YM0PgGPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XwCtH8Y0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VvAgeT1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eH4OizJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nO2Td1EQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D7E78vAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ClyVrau1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OU2yex1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ohbn5un4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_X1YM9Usc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OvrqXk3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Uli9K5m7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9IxJBJWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_blQV4ETC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_86q6EaXb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SQTfMelw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gHo20sT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vt8gi90n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7YKfuKKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ia0uQQoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ojWmVn4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IFjdAjOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHIk9CIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PvGIiQPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2APOO3gK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mP7BNJe4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EXjcjKH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_shOIVz2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eXWBj9Ou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aXq7e6Yk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dox0tF5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T2E0QXBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XP9J9EqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9hEhXSZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QvvkYsqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pfQTvklY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tkrDbNw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_dKVW0AWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f1MacDnn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iKRTiOAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r96KUojm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WpcWqiPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Of454zAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OU8hodHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LwVtwfxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yCwoTQtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x3HyBhr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8ZGWneeP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pHvFZn0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4vXmaGRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jw2C1G63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ss7QubMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MOzZ6kRf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d99rom4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yuj183PQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_trNZTGCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pj8KOjJc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IMRNKVrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_htctJf9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IUE2kuvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bencSBMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qynOx1u5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cX8sZ4yn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XSND9aXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ImLOm9yn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wekhFQbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_i3V9Mr0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yYYqJoB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YPyEEgIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BxqCQgEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5TRP8ZRD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EXS7LAMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZHPD6VoI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p9nKKZme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lsLhhJi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fCJNtJYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q25WUk4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BDsy9yM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5YkGRqKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mp94svzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k3B90GWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OsOwzLrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lgbmXgou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OqZdDCGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4Mj4bTD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jU2cbeHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YvJEcAfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUAii6v8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qOzkjiaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BfJshq0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yihHXdDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fwuUvkTa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yxc36B2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_crm90sAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6s72cQVA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TUPdDjhG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_173G9x5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EQIPRiNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ny5DpWSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6voDyJsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fz5q30Jn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nASqWNJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BU6Jtutg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AEGvbfAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KdM0SUuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qgAsDxE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SUWmrST2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EZPunmIx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1i8IdZ8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fcZdg9aT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wAHcje9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2LJ4KRr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_be1pLn4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z68ruZX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TWsbiTJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gqvcBk5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BEElegF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2chxV3KR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8XJVNlhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ygfGIR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WXCVEy1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HAX8kXHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_f9KHJ9Rr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_POYnw4LU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pHipDLJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbLdVK8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jzK0E8GT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FMgeHqKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ShMz01Fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rRat2mks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iMroaqno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Iwlxwza7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B8Lk2Pqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tmIZA0Rl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_856YjyPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_atgqnZS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AGPa5OZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mIki3Rq2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WtgSBote_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NrxNt8oq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yTxBpZiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mymG4Uug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9qBIDvL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PMNKirha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GQpuH5lo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aDAnY0dV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bWv2FKYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UTLvwjqm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3CNd9i8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IRGokDwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1TsAtOYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WDAUmzwL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XM4F1R1i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWZzT7BT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3LfrWplv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WwaLg0GN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_22JKppjF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8NJ0Cfgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ClDEXb4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GjqBZmIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BzzOXkEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3w6wJDGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M4TJ850P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KXh7EvrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mKO9RuiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2WWVAPRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zpnj2SI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6aqs5mlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qcN2N700_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_OUPyW3pF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N9peZyN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UYSX8QOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EWi05YhI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4SbQZYr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NBLhSu3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Hdp5clZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ABTNpW1m_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ejDZkAhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lfPfFldq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GFOd5Gdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cfo3h2P0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_dox3die0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bkcubvPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MI8fu2S5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h8f1Gd8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x95ZdRUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qLvl2hkL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6hCi9gOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nj4zTF0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hLNtEOpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_w6EZ39aI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4QGYX91s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_inZLZcp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oGNwd7Qc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RQBpCIrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OM6xdzXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSPpxs9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WYbOG0VU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cdKtm3FJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEIImgtl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rjh9u6Jd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jSpgFOcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d1bqGtPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4y2S2WmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MTcG9YH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U7ERDbNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qhcGa9rj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yOxL9ZmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zSndtFQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g5KpXmud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MFr90wd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zWiVTQK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iRcw4dQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5UmNm4XJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6hI2lQDI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EhZTmi8A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l2qGP0FA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5erDXdq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VGagSW3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PkLwRMtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_a69wGZKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ImU77Qmk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RYz7Ot4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_97dubFYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ykFiFq6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1fqSxrEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uxPL1BnG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XhrTBmYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d4B2pMJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FV6gJOpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yDq9oEva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H8fd0Mnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DWKvmkc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7igHkh8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LA5vnVya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EWZOGgCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oJZvCEUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TFQ1ZnOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mzFxYNgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wz8YmxtP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9lIjBjJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iNTKcJXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o2itpKAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZgcA0ltK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fmz6C1fZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QHDaNneq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bUHWtvY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HznJpTCi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LyAzZFXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bT0r0tW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VAcRxxmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YqUk34Vz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d425dd0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WZUautW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_b2PuLlgN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PfdkmUGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eG61O2zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YuN1hMOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F1a4gClF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CFe1vr01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jAuEtkkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fBqymIcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a6gja8xz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rwaf8cHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cXFbSrB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WaiWwADz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Jau0kv9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QCuUXi2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HbemS6Mw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QlL0vqVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_q5DUi8f3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_t5aVFwUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_c8CPEGBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D7bqnh39_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8b4SUqxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QTtEMyOP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zj7vw8YM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xeOQrNvE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PXFX1tni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrODM9FU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0o4SWa2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tzhc2NDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hDW430tv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JWHB774W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L9vqfINc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KzQR6V72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZeF1CuVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WfcLVitJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_84DJZMtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WevPKAAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z8HOqDn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FoKQSddd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZXvk3y75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l6j52DpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jGpPFz1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m6lc8l9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hr2T3g9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iQFBTAPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MmcseBHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qzcytrqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KDlwL7oe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hy89eAU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M6IYWwzc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kc6VPz86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5tE6ftqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zSwJPQIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D7vT4oqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2mk5Vleu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x0JBzFoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fZpcqe9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TX7Nqucr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EtTswrWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v604g5xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mtlN8wGr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7NYpTc5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QQReDVo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XqtQrEEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F04ZYsvk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3OsKPC9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tw4Do639_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jRLvtj4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sPl8X5iY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NaDNOKJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iXCyTSvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y7enKTP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rTe42oyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NgYArD7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aueZgy0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NuzEVbAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ERkdBS3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2KiHdpBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ut0PZbmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QZaZTOV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ymhfqh7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uEdrhh5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mnOspg8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QxZMvCS2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yBwNZPOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A3Nod9cL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dSINX0JX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DbnkiVK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HTT0k1iD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DfJOZ6gR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oTPbCEFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FKrtuZng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1OxcOhem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ufJmjpjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jAPQwNsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DW85qu8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1df66Wnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O1JFEmjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mReWKW7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JjoLgbAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fBCQn2fU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJvedS1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D5clmys9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Yn3DRUSv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SxRpcLOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MkQmCwF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5HarTTJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o7fchvbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7tfggHwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8YnTwanS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I1Z48g3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HpG7Eh7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Fo2z3DrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KW6wKHz4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eUNpnAmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xpKObm8D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M0hMoAS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s0m4kn4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOFkR6uJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OhQCXyVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D6Ljhtd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UOLs8sru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Di0sHYP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mAnNRUvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rNITCFaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8iDf9ghe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P76kGqUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_McALSAaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9F5XxH29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_d1gHa02S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ekNVqVCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ptUgfZMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_euLqAamA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c05wVMdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r4fNrldN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_waekoRAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k9lK26Gp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OkiJDTyx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oHuneJY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jT9wvm6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ozaL4A03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4ckukjVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bNOHM4Sd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6lvLnBXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rPGueocd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sv13hkMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LQUqA32F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_btlcaW8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0EcDVfCC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OJnyVr2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rpSKUABm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ILbhYYGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ubtl3rQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6GcyHjQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qbIJ8IFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gSxtFKuQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R968yQPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_vTLkNvUp;
  SignalLine sLine_qdx6aReO;
  SignalLine sLine_XzYDv7R6;
  SignalLine sLine_MQolr9at;
  SignalLine sLine_geTh6lvG;
  SignalBiquad sBiquad_s_glyMaCqs;
  SignalLine sLine_uB5vbDQb;
  SignalLine sLine_izFUuA9c;
  SignalLine sLine_kEO1bAAX;
  SignalLine sLine_Q93Tseen;
  SignalBiquad sBiquad_s_IAFO4QD0;
  SignalLine sLine_eq2HNDXA;
  SignalLine sLine_VdvzjSfp;
  SignalLine sLine_lLnVxQQV;
  SignalLine sLine_9vUPJU0V;
  SignalLine sLine_BbmXqiC6;
  SignalBiquad sBiquad_s_fOTtrF5U;
  SignalLine sLine_2PK8jyMQ;
  SignalLine sLine_5MuqLTp3;
  SignalLine sLine_NL5TNX37;
  SignalLine sLine_rUacWcFK;
  SignalLine sLine_Vu0SIyNh;
  SignalBiquad sBiquad_s_4jEQiCQ3;
  SignalLine sLine_84yPUZHU;
  SignalLine sLine_5kawRpkU;
  SignalLine sLine_L0fV7bpK;
  SignalLine sLine_c6pni4SS;
  SignalBiquad sBiquad_s_MPWoMkVx;
  SignalLine sLine_qaakaDaQ;
  SignalLine sLine_qkv5ta5R;
  SignalLine sLine_RmvUjBDT;
  SignalLine sLine_v2am3THf;
  SignalLine sLine_TFszBrdR;
  SignalBiquad sBiquad_s_fNFJeLtm;
  ControlVar cVar_H6vLgg9j;
  ControlVar cVar_MV5LLL1Q;
  ControlVar cVar_0uMDkVNu;
  ControlVar cVar_HgM0N5Kk;
  ControlSlice cSlice_s7toOusK;
  ControlVar cVar_H9onsVOh;
  ControlVar cVar_wvRaefjx;
  ControlIf cIf_ytZ80B4y;
  ControlIf cIf_AKfP8c4l;
  ControlBinop cBinop_TtcMOlx0;
  ControlBinop cBinop_HnbAYR7c;
  ControlBinop cBinop_kbf7QNe9;
  ControlBinop cBinop_WFS280cJ;
  ControlBinop cBinop_oGKP0OxD;
  ControlIf cIf_gNn28FuO;
  ControlBinop cBinop_bT8wJgaX;
  ControlBinop cBinop_RH3qRHqy;
  ControlBinop cBinop_GqwiPRvB;
  ControlBinop cBinop_TuJqe8DH;
  ControlBinop cBinop_YY59L4Kc;
  ControlVar cVar_RO9EHkPj;
  ControlIf cIf_gpBC7nYs;
  ControlIf cIf_WMemUAjA;
  ControlBinop cBinop_GMJkIXCD;
  ControlBinop cBinop_vwXng290;
  ControlBinop cBinop_XZLQxEma;
  ControlBinop cBinop_beDh3HoS;
  ControlBinop cBinop_6EkTqaVR;
  ControlIf cIf_r21CRfKc;
  ControlBinop cBinop_z8SDR2sb;
  ControlBinop cBinop_W3t3L0Vm;
  ControlBinop cBinop_wZ97c7Yq;
  ControlBinop cBinop_FRj6d58f;
  ControlBinop cBinop_u4oC2AAJ;
  ControlVar cVar_Sb0wBEqm;
  ControlIf cIf_hF2WXoYA;
  ControlIf cIf_SvgMn3A4;
  ControlBinop cBinop_GTt0By0O;
  ControlBinop cBinop_ib25Gjtt;
  ControlBinop cBinop_lPZwG58M;
  ControlBinop cBinop_910wGhLl;
  ControlBinop cBinop_EcKnk8Re;
  ControlIf cIf_sXi3TT7j;
  ControlBinop cBinop_eLgfc2O1;
  ControlBinop cBinop_MZrM8EAb;
  ControlBinop cBinop_DG7AGp2S;
  ControlBinop cBinop_2lIh3RpF;
  ControlBinop cBinop_utBl0KZH;
  ControlIf cIf_4lPVwzP7;
  ControlSlice cSlice_l56FawAH;
  ControlVar cVar_VS3yf615;
  ControlSlice cSlice_7EuKpCMx;
  ControlVar cVar_01byo3fo;
  ControlSlice cSlice_rALyv4K3;
  ControlVar cVar_6CIUOA37;
  ControlSlice cSlice_sTrNphHw;
  ControlVar cVar_tavRIZer;
  ControlBinop cBinop_OBbIyzbM;
  ControlBinop cBinop_tdgr2Umw;
  ControlBinop cBinop_9ey2MYqY;
  ControlBinop cBinop_DQxqRSyN;
  ControlBinop cBinop_0IpyfSOx;
  ControlBinop cBinop_7agLf46Q;
  ControlBinop cBinop_yLzkHUMI;
  ControlBinop cBinop_WEgyCkzU;
  ControlVar cVar_MUrzKMen;
  ControlBinop cBinop_PySljEmn;
  ControlBinop cBinop_ZoKNuS4E;
  ControlBinop cBinop_Hf7YCvui;
  ControlBinop cBinop_j39p0EHN;
  ControlBinop cBinop_YV2cInC3;
  ControlBinop cBinop_Ip2VllZM;
  ControlBinop cBinop_efljQA6g;
  ControlBinop cBinop_w3XpGamq;
  ControlVar cVar_lurXnupj;
  ControlVar cVar_TuWwvntM;
  ControlBinop cBinop_9BYB464v;
  ControlBinop cBinop_jz5KUuAf;
  ControlBinop cBinop_6WtOxkFr;
  ControlBinop cBinop_kJTm3opz;
  ControlBinop cBinop_oYbM7ONi;
  ControlBinop cBinop_LxGnbmrh;
  ControlBinop cBinop_mXkCX2R2;
  ControlBinop cBinop_eag34nUR;
  ControlBinop cBinop_Imq2OfJ4;
  ControlBinop cBinop_byWrhKAA;
  ControlBinop cBinop_xMG6qOTd;
  ControlBinop cBinop_cewrW6yz;
  ControlBinop cBinop_ximKUoS7;
  ControlBinop cBinop_uSzAmenp;
  ControlBinop cBinop_cKEbHHbb;
  ControlBinop cBinop_W85ovcoM;
  ControlBinop cBinop_aDFm7uQH;
  ControlBinop cBinop_YM0PgGPt;
  ControlBinop cBinop_XwCtH8Y0;
  ControlBinop cBinop_eH4OizJj;
  ControlVar cVar_nO2Td1EQ;
  ControlVar cVar_D7E78vAs;
  ControlVar cVar_ClyVrau1;
  ControlBinop cBinop_blQV4ETC;
  ControlBinop cBinop_86q6EaXb;
  ControlBinop cBinop_SQTfMelw;
  ControlBinop cBinop_Vt8gi90n;
  ControlBinop cBinop_7YKfuKKo;
  ControlBinop cBinop_Ia0uQQoP;
  ControlBinop cBinop_ojWmVn4b;
  ControlBinop cBinop_IFjdAjOE;
  ControlBinop cBinop_iKRTiOAW;
  ControlBinop cBinop_WpcWqiPZ;
  ControlBinop cBinop_Of454zAc;
  ControlBinop cBinop_yCwoTQtH;
  ControlBinop cBinop_x3HyBhr3;
  ControlBinop cBinop_8ZGWneeP;
  ControlBinop cBinop_pHvFZn0z;
  ControlBinop cBinop_4vXmaGRb;
  ControlBinop cBinop_Ss7QubMF;
  ControlBinop cBinop_d99rom4n;
  ControlBinop cBinop_Yuj183PQ;
  ControlBinop cBinop_pj8KOjJc;
  ControlBinop cBinop_IMRNKVrn;
  ControlBinop cBinop_htctJf9A;
  ControlBinop cBinop_bencSBMZ;
  ControlVar cVar_qynOx1u5;
  ControlVar cVar_cX8sZ4yn;
  ControlVar cVar_XSND9aXM;
  ControlBinop cBinop_5TRP8ZRD;
  ControlBinop cBinop_EXS7LAMZ;
  ControlBinop cBinop_ZHPD6VoI;
  ControlBinop cBinop_lsLhhJi4;
  ControlBinop cBinop_fCJNtJYi;
  ControlBinop cBinop_Q25WUk4K;
  ControlBinop cBinop_BDsy9yM0;
  ControlBinop cBinop_5YkGRqKA;
  ControlBinop cBinop_mp94svzR;
  ControlBinop cBinop_yihHXdDd;
  ControlBinop cBinop_Yxc36B2m;
  ControlBinop cBinop_crm90sAi;
  SignalVarf sVarf_w5iAgm9F;
  SignalVarf sVarf_bmW8vMSg;
  SignalVarf sVarf_Jnw6v0v1;
  ControlSlice cSlice_TUPdDjhG;
  ControlVar cVar_173G9x5O;
  ControlVar cVar_ny5DpWSt;
  ControlIf cIf_6voDyJsz;
  ControlIf cIf_fz5q30Jn;
  ControlBinop cBinop_BU6Jtutg;
  ControlBinop cBinop_AEGvbfAP;
  ControlBinop cBinop_SUWmrST2;
  ControlBinop cBinop_EZPunmIx;
  ControlBinop cBinop_fcZdg9aT;
  ControlIf cIf_wAHcje9b;
  ControlBinop cBinop_2LJ4KRr8;
  ControlBinop cBinop_be1pLn4s;
  ControlBinop cBinop_TWsbiTJd;
  ControlBinop cBinop_gqvcBk5f;
  ControlBinop cBinop_9BEElegF;
  ControlVar cVar_HAX8kXHg;
  ControlIf cIf_f9KHJ9Rr;
  ControlIf cIf_POYnw4LU;
  ControlBinop cBinop_gbLdVK8N;
  ControlBinop cBinop_jzK0E8GT;
  ControlBinop cBinop_rRat2mks;
  ControlBinop cBinop_iMroaqno;
  ControlBinop cBinop_B8Lk2Pqf;
  ControlIf cIf_tmIZA0Rl;
  ControlBinop cBinop_856YjyPO;
  ControlBinop cBinop_atgqnZS1;
  ControlBinop cBinop_mIki3Rq2;
  ControlBinop cBinop_WtgSBote;
  ControlBinop cBinop_NrxNt8oq;
  ControlVar cVar_GQpuH5lo;
  ControlIf cIf_aDAnY0dV;
  ControlIf cIf_bWv2FKYT;
  ControlBinop cBinop_3CNd9i8x;
  ControlBinop cBinop_IRGokDwv;
  ControlBinop cBinop_XM4F1R1i;
  ControlBinop cBinop_nWZzT7BT;
  ControlBinop cBinop_WwaLg0GN;
  ControlIf cIf_22JKppjF;
  ControlBinop cBinop_8NJ0Cfgu;
  ControlBinop cBinop_ClDEXb4Z;
  ControlBinop cBinop_BzzOXkEE;
  ControlBinop cBinop_3w6wJDGU;
  ControlBinop cBinop_M4TJ850P;
  ControlIf cIf_6aqs5mlF;
  ControlSlice cSlice_OUPyW3pF;
  ControlVar cVar_N9peZyN5;
  ControlSlice cSlice_4SbQZYr1;
  ControlVar cVar_NBLhSu3o;
  ControlSlice cSlice_ejDZkAhj;
  ControlVar cVar_lfPfFldq;
  ControlSlice cSlice_dox3die0;
  ControlVar cVar_bkcubvPH;
  ControlBinop cBinop_oGNwd7Qc;
  ControlBinop cBinop_OM6xdzXt;
  ControlBinop cBinop_qSPpxs9H;
  ControlBinop cBinop_IEIImgtl;
  ControlBinop cBinop_rjh9u6Jd;
  ControlBinop cBinop_jSpgFOcE;
  ControlBinop cBinop_d1bqGtPz;
  ControlBinop cBinop_4y2S2WmD;
  ControlVar cVar_MTcG9YH7;
  ControlBinop cBinop_U7ERDbNQ;
  ControlBinop cBinop_qhcGa9rj;
  ControlBinop cBinop_yOxL9ZmJ;
  ControlBinop cBinop_zSndtFQH;
  ControlBinop cBinop_g5KpXmud;
  ControlBinop cBinop_MFr90wd1;
  ControlBinop cBinop_zWiVTQK8;
  ControlBinop cBinop_5UmNm4XJ;
  ControlVar cVar_6hI2lQDI;
  ControlVar cVar_EhZTmi8A;
  ControlBinop cBinop_RYz7Ot4O;
  ControlBinop cBinop_97dubFYQ;
  ControlBinop cBinop_ykFiFq6S;
  ControlBinop cBinop_uxPL1BnG;
  ControlBinop cBinop_XhrTBmYy;
  ControlBinop cBinop_d4B2pMJj;
  ControlBinop cBinop_FV6gJOpK;
  ControlBinop cBinop_yDq9oEva;
  ControlBinop cBinop_H8fd0Mnr;
  ControlBinop cBinop_VAcRxxmL;
  ControlBinop cBinop_d425dd0B;
  ControlBinop cBinop_WZUautW2;
  ControlBinop cBinop_eG61O2zb;
  ControlBinop cBinop_YuN1hMOw;
  ControlBinop cBinop_F1a4gClF;
  ControlBinop cBinop_CFe1vr01;
  ControlBinop cBinop_jAuEtkkb;
  ControlBinop cBinop_fBqymIcL;
  ControlBinop cBinop_a6gja8xz;
  ControlBinop cBinop_cXFbSrB8;
  ControlVar cVar_WaiWwADz;
  ControlVar cVar_Jau0kv9Y;
  ControlVar cVar_QCuUXi2s;
  ControlBinop cBinop_8b4SUqxr;
  ControlBinop cBinop_QTtEMyOP;
  ControlBinop cBinop_zj7vw8YM;
  ControlBinop cBinop_PXFX1tni;
  ControlBinop cBinop_yrODM9FU;
  ControlBinop cBinop_0o4SWa2E;
  ControlBinop cBinop_tzhc2NDm;
  ControlBinop cBinop_hDW430tv;
  ControlBinop cBinop_KDlwL7oe;
  ControlBinop cBinop_M6IYWwzc;
  ControlBinop cBinop_Kc6VPz86;
  ControlBinop cBinop_D7vT4oqa;
  ControlBinop cBinop_2mk5Vleu;
  ControlBinop cBinop_x0JBzFoP;
  ControlBinop cBinop_fZpcqe9K;
  ControlBinop cBinop_TX7Nqucr;
  ControlBinop cBinop_v604g5xw;
  ControlBinop cBinop_7NYpTc5F;
  ControlBinop cBinop_QQReDVo3;
  ControlBinop cBinop_F04ZYsvk;
  ControlBinop cBinop_3OsKPC9P;
  ControlBinop cBinop_tw4Do639;
  ControlBinop cBinop_sPl8X5iY;
  ControlVar cVar_NaDNOKJZ;
  ControlVar cVar_iXCyTSvf;
  ControlVar cVar_y7enKTP2;
  ControlBinop cBinop_Ut0PZbmI;
  ControlBinop cBinop_QZaZTOV6;
  ControlBinop cBinop_Ymhfqh7B;
  ControlBinop cBinop_mnOspg8z;
  ControlBinop cBinop_QxZMvCS2;
  ControlBinop cBinop_yBwNZPOJ;
  ControlBinop cBinop_A3Nod9cL;
  ControlBinop cBinop_dSINX0JX;
  ControlBinop cBinop_DbnkiVK9;
  ControlBinop cBinop_mReWKW7Y;
  ControlBinop cBinop_fBCQn2fU;
  ControlBinop cBinop_bJvedS1C;
  SignalVarf sVarf_xRwMUyw5;
  SignalVarf sVarf_xA1GIv2x;
  SignalVarf sVarf_OdO1PBCu;
  SignalVarf sVarf_or1coXb9;
  SignalVarf sVarf_JJoK4Ns8;
  SignalVarf sVarf_pW8pfcbD;
  SignalVarf sVarf_0mTINLCR;
  SignalVarf sVarf_ZVcWQjET;
  SignalVarf sVarf_cr0EqZOt;
  ControlVar cVar_D5clmys9;
  ControlVar cVar_Yn3DRUSv;
  ControlBinop cBinop_8YnTwanS;
  ControlBinop cBinop_I1Z48g3j;
  ControlBinop cBinop_HpG7Eh7L;
  ControlBinop cBinop_KW6wKHz4;
  ControlBinop cBinop_eUNpnAmx;
  ControlBinop cBinop_xpKObm8D;
  ControlBinop cBinop_M0hMoAS8;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
