/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_vTLkNvUp);
  numBytes += sLine_init(&sLine_qdx6aReO);
  numBytes += sLine_init(&sLine_XzYDv7R6);
  numBytes += sLine_init(&sLine_MQolr9at);
  numBytes += sLine_init(&sLine_geTh6lvG);
  numBytes += sBiquad_init(&sBiquad_s_glyMaCqs);
  numBytes += sLine_init(&sLine_uB5vbDQb);
  numBytes += sLine_init(&sLine_izFUuA9c);
  numBytes += sLine_init(&sLine_kEO1bAAX);
  numBytes += sLine_init(&sLine_Q93Tseen);
  numBytes += sBiquad_init(&sBiquad_s_IAFO4QD0);
  numBytes += sLine_init(&sLine_eq2HNDXA);
  numBytes += sLine_init(&sLine_VdvzjSfp);
  numBytes += sLine_init(&sLine_lLnVxQQV);
  numBytes += sLine_init(&sLine_9vUPJU0V);
  numBytes += sLine_init(&sLine_BbmXqiC6);
  numBytes += sBiquad_init(&sBiquad_s_fOTtrF5U);
  numBytes += sLine_init(&sLine_2PK8jyMQ);
  numBytes += sLine_init(&sLine_5MuqLTp3);
  numBytes += sLine_init(&sLine_NL5TNX37);
  numBytes += sLine_init(&sLine_rUacWcFK);
  numBytes += sLine_init(&sLine_Vu0SIyNh);
  numBytes += sBiquad_init(&sBiquad_s_4jEQiCQ3);
  numBytes += sLine_init(&sLine_84yPUZHU);
  numBytes += sLine_init(&sLine_5kawRpkU);
  numBytes += sLine_init(&sLine_L0fV7bpK);
  numBytes += sLine_init(&sLine_c6pni4SS);
  numBytes += sBiquad_init(&sBiquad_s_MPWoMkVx);
  numBytes += sLine_init(&sLine_qaakaDaQ);
  numBytes += sLine_init(&sLine_qkv5ta5R);
  numBytes += sLine_init(&sLine_RmvUjBDT);
  numBytes += sLine_init(&sLine_v2am3THf);
  numBytes += sLine_init(&sLine_TFszBrdR);
  numBytes += sBiquad_init(&sBiquad_s_fNFJeLtm);
  numBytes += cVar_init_f(&cVar_H6vLgg9j, 0.0f);
  numBytes += cVar_init_f(&cVar_MV5LLL1Q, 0.0f);
  numBytes += cVar_init_f(&cVar_0uMDkVNu, 0.0f);
  numBytes += cVar_init_f(&cVar_HgM0N5Kk, 0.0f);
  numBytes += cSlice_init(&cSlice_s7toOusK, 1, -1);
  numBytes += cVar_init_f(&cVar_H9onsVOh, 1337.0f);
  numBytes += cVar_init_f(&cVar_wvRaefjx, 0.0f);
  numBytes += cIf_init(&cIf_ytZ80B4y, false);
  numBytes += cIf_init(&cIf_AKfP8c4l, false);
  numBytes += cBinop_init(&cBinop_TtcMOlx0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gNn28FuO, false);
  numBytes += cBinop_init(&cBinop_GqwiPRvB, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TuJqe8DH, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YY59L4Kc, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_RO9EHkPj, 0.0f);
  numBytes += cIf_init(&cIf_gpBC7nYs, false);
  numBytes += cIf_init(&cIf_WMemUAjA, false);
  numBytes += cBinop_init(&cBinop_GMJkIXCD, 0.0f); // __pow
  numBytes += cIf_init(&cIf_r21CRfKc, false);
  numBytes += cBinop_init(&cBinop_wZ97c7Yq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_FRj6d58f, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_u4oC2AAJ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Sb0wBEqm, 0.0f);
  numBytes += cIf_init(&cIf_hF2WXoYA, false);
  numBytes += cIf_init(&cIf_SvgMn3A4, false);
  numBytes += cBinop_init(&cBinop_GTt0By0O, 0.0f); // __pow
  numBytes += cIf_init(&cIf_sXi3TT7j, false);
  numBytes += cBinop_init(&cBinop_DG7AGp2S, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_2lIh3RpF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_utBl0KZH, -15.0f); // __eq
  numBytes += cIf_init(&cIf_4lPVwzP7, false);
  numBytes += cSlice_init(&cSlice_l56FawAH, 1, -1);
  numBytes += cVar_init_f(&cVar_VS3yf615, 0.0f);
  numBytes += cSlice_init(&cSlice_7EuKpCMx, 1, -1);
  numBytes += cVar_init_f(&cVar_01byo3fo, 0.0f);
  numBytes += cSlice_init(&cSlice_rALyv4K3, 1, -1);
  numBytes += cVar_init_f(&cVar_6CIUOA37, 0.0f);
  numBytes += cSlice_init(&cSlice_sTrNphHw, 1, -1);
  numBytes += cVar_init_f(&cVar_tavRIZer, 0.313f);
  numBytes += cBinop_init(&cBinop_tdgr2Umw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_9ey2MYqY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MUrzKMen, 0.0f);
  numBytes += cVar_init_f(&cVar_lurXnupj, 1337.0f);
  numBytes += cVar_init_f(&cVar_TuWwvntM, 0.3f);
  numBytes += cBinop_init(&cBinop_jz5KUuAf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oYbM7ONi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LxGnbmrh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mXkCX2R2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eag34nUR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Imq2OfJ4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xMG6qOTd, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cewrW6yz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_nO2Td1EQ, 0.0f);
  numBytes += cVar_init_f(&cVar_D7E78vAs, 1337.0f);
  numBytes += cVar_init_f(&cVar_ClyVrau1, 0.313f);
  numBytes += cBinop_init(&cBinop_86q6EaXb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7YKfuKKo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ia0uQQoP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ojWmVn4b, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IFjdAjOE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WpcWqiPZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Of454zAc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qynOx1u5, 0.0f);
  numBytes += cVar_init_f(&cVar_cX8sZ4yn, 1037.0f);
  numBytes += cVar_init_f(&cVar_XSND9aXM, 0.4f);
  numBytes += cBinop_init(&cBinop_EXS7LAMZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fCJNtJYi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q25WUk4K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BDsy9yM0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5YkGRqKA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mp94svzR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_w5iAgm9F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bmW8vMSg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Jnw6v0v1, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_TUPdDjhG, 1, -1);
  numBytes += cVar_init_f(&cVar_173G9x5O, 1337.0f);
  numBytes += cVar_init_f(&cVar_ny5DpWSt, 0.0f);
  numBytes += cIf_init(&cIf_6voDyJsz, false);
  numBytes += cIf_init(&cIf_fz5q30Jn, false);
  numBytes += cBinop_init(&cBinop_BU6Jtutg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_wAHcje9b, false);
  numBytes += cBinop_init(&cBinop_TWsbiTJd, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_gqvcBk5f, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9BEElegF, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_HAX8kXHg, 0.0f);
  numBytes += cIf_init(&cIf_f9KHJ9Rr, false);
  numBytes += cIf_init(&cIf_POYnw4LU, false);
  numBytes += cBinop_init(&cBinop_gbLdVK8N, 0.0f); // __pow
  numBytes += cIf_init(&cIf_tmIZA0Rl, false);
  numBytes += cBinop_init(&cBinop_mIki3Rq2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WtgSBote, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NrxNt8oq, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_GQpuH5lo, 0.0f);
  numBytes += cIf_init(&cIf_aDAnY0dV, false);
  numBytes += cIf_init(&cIf_bWv2FKYT, false);
  numBytes += cBinop_init(&cBinop_3CNd9i8x, 0.0f); // __pow
  numBytes += cIf_init(&cIf_22JKppjF, false);
  numBytes += cBinop_init(&cBinop_BzzOXkEE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_3w6wJDGU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_M4TJ850P, -15.0f); // __eq
  numBytes += cIf_init(&cIf_6aqs5mlF, false);
  numBytes += cSlice_init(&cSlice_OUPyW3pF, 1, -1);
  numBytes += cVar_init_f(&cVar_N9peZyN5, 0.0f);
  numBytes += cSlice_init(&cSlice_4SbQZYr1, 1, -1);
  numBytes += cVar_init_f(&cVar_NBLhSu3o, 0.0f);
  numBytes += cSlice_init(&cSlice_ejDZkAhj, 1, -1);
  numBytes += cVar_init_f(&cVar_lfPfFldq, 0.0f);
  numBytes += cSlice_init(&cSlice_dox3die0, 1, -1);
  numBytes += cVar_init_f(&cVar_bkcubvPH, 0.313f);
  numBytes += cBinop_init(&cBinop_OM6xdzXt, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qSPpxs9H, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MTcG9YH7, 0.0f);
  numBytes += cVar_init_f(&cVar_6hI2lQDI, 1337.0f);
  numBytes += cVar_init_f(&cVar_EhZTmi8A, 0.3f);
  numBytes += cBinop_init(&cBinop_97dubFYQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XhrTBmYy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d4B2pMJj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FV6gJOpK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yDq9oEva, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H8fd0Mnr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_d425dd0B, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_WZUautW2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WaiWwADz, 0.0f);
  numBytes += cVar_init_f(&cVar_Jau0kv9Y, 1337.0f);
  numBytes += cVar_init_f(&cVar_QCuUXi2s, 0.313f);
  numBytes += cBinop_init(&cBinop_QTtEMyOP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yrODM9FU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0o4SWa2E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tzhc2NDm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hDW430tv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M6IYWwzc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Kc6VPz86, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_NaDNOKJZ, 0.0f);
  numBytes += cVar_init_f(&cVar_iXCyTSvf, 1037.0f);
  numBytes += cVar_init_f(&cVar_y7enKTP2, 0.4f);
  numBytes += cBinop_init(&cBinop_QZaZTOV6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QxZMvCS2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yBwNZPOJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_A3Nod9cL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dSINX0JX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DbnkiVK9, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_xRwMUyw5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xA1GIv2x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OdO1PBCu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_or1coXb9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JJoK4Ns8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pW8pfcbD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0mTINLCR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZVcWQjET, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cr0EqZOt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_D5clmys9, 5705.6f);
  numBytes += cVar_init_f(&cVar_Yn3DRUSv, 313.3f);
  numBytes += cBinop_init(&cBinop_8YnTwanS, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_I1Z48g3j, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_HpG7Eh7L, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rNITCFaj_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P76kGqUi_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8iDf9ghe_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R968yQPP_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d1gHa02S_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ekNVqVCA_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_McALSAaH_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9F5XxH29_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ptUgfZMc_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_waekoRAw_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r4fNrldN_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c05wVMdE_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oHuneJY6_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OkiJDTyx_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k9lK26Gp_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4ckukjVI_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ozaL4A03_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jT9wvm6S_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rPGueocd_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sv13hkMp_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bNOHM4Sd_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6lvLnBXR_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LQUqA32F_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OJnyVr2R_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0EcDVfCC_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_btlcaW8t_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ubtl3rQm_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ILbhYYGM_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rpSKUABm_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gSxtFKuQ_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qbIJ8IFG_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6GcyHjQX_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_euLqAamA_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_H6vLgg9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s0m4kn4O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_MV5LLL1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LOFkR6uJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_0uMDkVNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OhQCXyVW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_HgM0N5Kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D6Ljhtd8_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7tfggHwC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o7fchvbA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5HarTTJL_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_AvVjakyH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_s7toOusK, 0, m, &cSlice_s7toOusK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ejiFkkLp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_s7toOusK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z5ihR74I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z5ihR74I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_H9onsVOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z5ihR74I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_z5ihR74I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_McALSAaH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_wvRaefjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bT8wJgaX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ytZ80B4y, 0, m, &cIf_ytZ80B4y_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ytZ80B4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RH3qRHqy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_AKfP8c4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JGYfKp6I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WFS280cJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_tF1MbIgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TtcMOlx0, HV_BINOP_POW, 0, m, &cBinop_TtcMOlx0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TtcMOlx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gNn28FuO, 0, m, &cIf_gNn28FuO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HnbAYR7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oGKP0OxD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WzhD11oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kbf7QNe9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LhPf6ynL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AKfP8c4l, 0, m, &cIf_AKfP8c4l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kbf7QNe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AKfP8c4l, 1, m, &cIf_AKfP8c4l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WFS280cJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HnbAYR7c_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JGYfKp6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gNn28FuO, 0, m, &cIf_gNn28FuO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oGKP0OxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TtcMOlx0, HV_BINOP_POW, 1, m, &cBinop_TtcMOlx0_sendMessage);
  cMsg_tF1MbIgU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_gNn28FuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_w5iAgm9F, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_bT8wJgaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ytZ80B4y, 1, m, &cIf_ytZ80B4y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RH3qRHqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TuJqe8DH, HV_BINOP_GREATER_THAN, 1, m, &cBinop_TuJqe8DH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YY59L4Kc, HV_BINOP_EQ, 1, m, &cBinop_YY59L4Kc_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sotJsbBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GqwiPRvB, HV_BINOP_ADD, 0, m, &cBinop_GqwiPRvB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GqwiPRvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WzhD11oa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LhPf6ynL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TuJqe8DH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gNn28FuO, 1, m, &cIf_gNn28FuO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YY59L4Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X3wt0wyx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_X3wt0wyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_w5iAgm9F, m);
}

void Heavy_WSTD_EQ::cCast_nnd0zuIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wvRaefjx, 0, m, &cVar_wvRaefjx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lw2cp81p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GqwiPRvB, HV_BINOP_ADD, 1, m, &cBinop_GqwiPRvB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TuJqe8DH, HV_BINOP_GREATER_THAN, 0, m, &cBinop_TuJqe8DH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YY59L4Kc, HV_BINOP_EQ, 0, m, &cBinop_YY59L4Kc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ebklagCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sotJsbBF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_RO9EHkPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_z8SDR2sb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gpBC7nYs, 0, m, &cIf_gpBC7nYs_sendMessage);
}

void Heavy_WSTD_EQ::cIf_gpBC7nYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_W3t3L0Vm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_WMemUAjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mOCbG0rP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_beDh3HoS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_rppfDOyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMJkIXCD, HV_BINOP_POW, 0, m, &cBinop_GMJkIXCD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GMJkIXCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r21CRfKc, 0, m, &cIf_r21CRfKc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vwXng290_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6EkTqaVR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_M2jOesf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMemUAjA, 0, m, &cIf_WMemUAjA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rSXpxM7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XZLQxEma_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XZLQxEma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMemUAjA, 1, m, &cIf_WMemUAjA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_beDh3HoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vwXng290_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mOCbG0rP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_r21CRfKc, 0, m, &cIf_r21CRfKc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6EkTqaVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMJkIXCD, HV_BINOP_POW, 1, m, &cBinop_GMJkIXCD_sendMessage);
  cMsg_rppfDOyp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_r21CRfKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yihHXdDd_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yxc36B2m_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_crm90sAi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_z8SDR2sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gpBC7nYs, 1, m, &cIf_gpBC7nYs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W3t3L0Vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FRj6d58f, HV_BINOP_GREATER_THAN, 1, m, &cBinop_FRj6d58f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_u4oC2AAJ, HV_BINOP_EQ, 1, m, &cBinop_u4oC2AAJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_OumIJH8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wZ97c7Yq, HV_BINOP_ADD, 0, m, &cBinop_wZ97c7Yq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wZ97c7Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rSXpxM7Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M2jOesf9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FRj6d58f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r21CRfKc, 1, m, &cIf_r21CRfKc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u4oC2AAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6gRKN6NH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6gRKN6NH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yihHXdDd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Yxc36B2m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_crm90sAi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1uC7Xty8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OumIJH8t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_jEoMSeOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wZ97c7Yq, HV_BINOP_ADD, 1, m, &cBinop_wZ97c7Yq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FRj6d58f, HV_BINOP_GREATER_THAN, 0, m, &cBinop_FRj6d58f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_u4oC2AAJ, HV_BINOP_EQ, 0, m, &cBinop_u4oC2AAJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_l3JNgsVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RO9EHkPj, 0, m, &cVar_RO9EHkPj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Sb0wBEqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eLgfc2O1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hF2WXoYA, 0, m, &cIf_hF2WXoYA_sendMessage);
}

void Heavy_WSTD_EQ::cIf_hF2WXoYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MZrM8EAb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_SvgMn3A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6tdvLEH0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_910wGhLl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_xUq3YXQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GTt0By0O, HV_BINOP_POW, 0, m, &cBinop_GTt0By0O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GTt0By0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXi3TT7j, 0, m, &cIf_sXi3TT7j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ib25Gjtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_EcKnk8Re_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uP8aoN0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lPZwG58M_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ki4zh8tF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SvgMn3A4, 0, m, &cIf_SvgMn3A4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lPZwG58M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SvgMn3A4, 1, m, &cIf_SvgMn3A4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_910wGhLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ib25Gjtt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6tdvLEH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sXi3TT7j, 0, m, &cIf_sXi3TT7j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EcKnk8Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GTt0By0O, HV_BINOP_POW, 1, m, &cBinop_GTt0By0O_sendMessage);
  cMsg_xUq3YXQG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_sXi3TT7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Jnw6v0v1, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_eLgfc2O1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hF2WXoYA, 1, m, &cIf_hF2WXoYA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MZrM8EAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2lIh3RpF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_2lIh3RpF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_utBl0KZH, HV_BINOP_EQ, 1, m, &cBinop_utBl0KZH_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZsVImThV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DG7AGp2S, HV_BINOP_ADD, 0, m, &cBinop_DG7AGp2S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DG7AGp2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uP8aoN0d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ki4zh8tF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2lIh3RpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXi3TT7j, 1, m, &cIf_sXi3TT7j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_utBl0KZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vkDIu5tU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_vkDIu5tU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Jnw6v0v1, m);
}

void Heavy_WSTD_EQ::cCast_u8aBZHEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sb0wBEqm, 0, m, &cVar_Sb0wBEqm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uuuPFwdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZsVImThV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_V2ggJQUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DG7AGp2S, HV_BINOP_ADD, 1, m, &cBinop_DG7AGp2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2lIh3RpF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_2lIh3RpF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_utBl0KZH, HV_BINOP_EQ, 0, m, &cBinop_utBl0KZH_sendMessage);
}

void Heavy_WSTD_EQ::cIf_4lPVwzP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bmW8vMSg, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_SdGUgDK9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l56FawAH, 0, m, &cSlice_l56FawAH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WLQ4tH13_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_l56FawAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0Crj4dog_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0Crj4dog_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_VS3yf615_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0Crj4dog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_0Crj4dog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_d1gHa02S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_WLQ4tH13_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7EuKpCMx, 0, m, &cSlice_7EuKpCMx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AvVjakyH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_7EuKpCMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LvoU9bnB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LvoU9bnB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_01byo3fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LvoU9bnB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_LvoU9bnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ptUgfZMc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ejiFkkLp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rALyv4K3, 0, m, &cSlice_rALyv4K3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HkJiQrQs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_rALyv4K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_77BeKubZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_77BeKubZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_6CIUOA37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_77BeKubZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_77BeKubZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ekNVqVCA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_HkJiQrQs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sTrNphHw, 0, m, &cSlice_sTrNphHw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_sTrNphHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9fauk4RI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9fauk4RI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_tavRIZer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9fauk4RI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_9fauk4RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9F5XxH29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gdLNt5Ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vTLkNvUp, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jcvTpwud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qdx6aReO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GiS2du5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XzYDv7R6, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uB578oVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MQolr9at, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Ep4zHCvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_geTh6lvG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_teC1x0NZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_omlD7L8C_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_omlD7L8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdgr2Umw, HV_BINOP_DIVIDE, 1, m, &cBinop_tdgr2Umw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iYDwc5ty_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_32E8hrnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OBbIyzbM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ls8TL4oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_32E8hrnM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OBbIyzbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tdgr2Umw, HV_BINOP_DIVIDE, 0, m, &cBinop_tdgr2Umw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iYDwc5ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ls8TL4oV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tdgr2Umw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ey2MYqY, HV_BINOP_MULTIPLY, 1, m, &cBinop_9ey2MYqY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9ey2MYqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k5K74lHw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LVYG1mPH_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_J4UPt5gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f7QpLzBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_3zWFPu8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pFOtA1Sa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DQxqRSyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0IpyfSOx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0IpyfSOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ey2MYqY, HV_BINOP_MULTIPLY, 0, m, &cBinop_9ey2MYqY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7agLf46Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_yLzkHUMI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yLzkHUMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AU7rnRjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WEgyCkzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MUrzKMen, 1, m, &cVar_MUrzKMen_sendMessage);
}

void Heavy_WSTD_EQ::cVar_MUrzKMen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6iONfEjr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PySljEmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oYbM7ONi, HV_BINOP_MULTIPLY, 1, m, &cBinop_oYbM7ONi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZoKNuS4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PySljEmn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hf7YCvui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_j39p0EHN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_j39p0EHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LxGnbmrh, HV_BINOP_MULTIPLY, 1, m, &cBinop_LxGnbmrh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YV2cInC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mXkCX2R2, HV_BINOP_MULTIPLY, 1, m, &cBinop_mXkCX2R2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ip2VllZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YV2cInC3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_efljQA6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eag34nUR, HV_BINOP_MULTIPLY, 1, m, &cBinop_eag34nUR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zFhDpmZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_w3XpGamq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_w3XpGamq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Imq2OfJ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_Imq2OfJ4_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lurXnupj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1bwlJpGV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_DQxqRSyN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1wPyxJJv_sendMessage);
}

void Heavy_WSTD_EQ::cVar_TuWwvntM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7agLf46Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LVYG1mPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3zWFPu8u_sendMessage);
}

void Heavy_WSTD_EQ::cCast_k5K74lHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_J4UPt5gb_sendMessage);
}

void Heavy_WSTD_EQ::cSend_f7QpLzBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c05wVMdE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_pFOtA1Sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r4fNrldN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ZwnxkRgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_waekoRAw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_AU7rnRjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9BYB464v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9BYB464v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jz5KUuAf, HV_BINOP_MULTIPLY, 1, m, &cBinop_jz5KUuAf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jz5KUuAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6WtOxkFr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6WtOxkFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZwnxkRgg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6iONfEjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kJTm3opz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kJTm3opz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RvdxxBuz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_00ztz0r6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kb6frjjZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gMiExA1t_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5WoHBmLC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MEAfNlHp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oYbM7ONi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gdLNt5Ht_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_LxGnbmrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jcvTpwud_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mXkCX2R2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GiS2du5j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_eag34nUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uB578oVK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Imq2OfJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ep4zHCvG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_ayq4heK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lurXnupj, 0, m, &cVar_lurXnupj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bRjgC1BD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TuWwvntM, 1, m, &cVar_TuWwvntM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_00ztz0r6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Imq2OfJ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_Imq2OfJ4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MEAfNlHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oYbM7ONi, HV_BINOP_MULTIPLY, 0, m, &cBinop_oYbM7ONi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RvdxxBuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_gMiExA1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mXkCX2R2, HV_BINOP_MULTIPLY, 0, m, &cBinop_mXkCX2R2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5WoHBmLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LxGnbmrh, HV_BINOP_MULTIPLY, 0, m, &cBinop_LxGnbmrh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kb6frjjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eag34nUR, HV_BINOP_MULTIPLY, 0, m, &cBinop_eag34nUR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1wPyxJJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MUrzKMen, 0, m, &cVar_MUrzKMen_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1bwlJpGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TuWwvntM, 0, m, &cVar_TuWwvntM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_hgzpbY01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uB5vbDQb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_HH7KHWp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_izFUuA9c, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_MNNhawQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kEO1bAAX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kq7n1p0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q93Tseen, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uId7lTnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xRa9Rhjh_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_xRa9Rhjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xMG6qOTd, HV_BINOP_DIVIDE, 1, m, &cBinop_xMG6qOTd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3aTZKv9O_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ZnuSf4dM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_byWrhKAA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_rfq0Nz6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZnuSf4dM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_byWrhKAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xMG6qOTd, HV_BINOP_DIVIDE, 0, m, &cBinop_xMG6qOTd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3aTZKv9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rfq0Nz6k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xMG6qOTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cewrW6yz, HV_BINOP_MULTIPLY, 1, m, &cBinop_cewrW6yz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cewrW6yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OU2yex1r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ohbn5un4_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xagRozaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X1YM9Usc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_5vTfrWeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OvrqXk3O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ximKUoS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_uSzAmenp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uSzAmenp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cewrW6yz, HV_BINOP_MULTIPLY, 0, m, &cBinop_cewrW6yz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cKEbHHbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_W85ovcoM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W85ovcoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9IxJBJWe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_aDFm7uQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ia0uQQoP, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ia0uQQoP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YM0PgGPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nO2Td1EQ, 1, m, &cVar_nO2Td1EQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XwCtH8Y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ojWmVn4b, HV_BINOP_MULTIPLY, 1, m, &cBinop_ojWmVn4b_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VvAgeT1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eH4OizJj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eH4OizJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IFjdAjOE, HV_BINOP_MULTIPLY, 1, m, &cBinop_IFjdAjOE_sendMessage);
}

void Heavy_WSTD_EQ::cVar_nO2Td1EQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gHo20sT6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_D7E78vAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mP7BNJe4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ximKUoS7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2APOO3gK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ClyVrau1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_cKEbHHbb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OU2yex1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xagRozaQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ohbn5un4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5vTfrWeg_sendMessage);
}

void Heavy_WSTD_EQ::cSend_X1YM9Usc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k9lK26Gp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_OvrqXk3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OkiJDTyx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Uli9K5m7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oHuneJY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9IxJBJWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_blQV4ETC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_blQV4ETC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_86q6EaXb, HV_BINOP_MULTIPLY, 1, m, &cBinop_86q6EaXb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_86q6EaXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SQTfMelw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SQTfMelw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Uli9K5m7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gHo20sT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Vt8gi90n_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Vt8gi90n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_shOIVz2J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EXjcjKH9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aXq7e6Yk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eXWBj9Ou_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7YKfuKKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hgzpbY01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ia0uQQoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HH7KHWp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ojWmVn4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MNNhawQn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IFjdAjOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kq7n1p0y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_HHIk9CIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D7E78vAs, 0, m, &cVar_D7E78vAs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PvGIiQPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ClyVrau1, 1, m, &cVar_ClyVrau1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2APOO3gK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nO2Td1EQ, 0, m, &cVar_nO2Td1EQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mP7BNJe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ClyVrau1, 0, m, &cVar_ClyVrau1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EXjcjKH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ojWmVn4b, HV_BINOP_MULTIPLY, 0, m, &cBinop_ojWmVn4b_sendMessage);
}

void Heavy_WSTD_EQ::cCast_shOIVz2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IFjdAjOE, HV_BINOP_MULTIPLY, 0, m, &cBinop_IFjdAjOE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eXWBj9Ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7YKfuKKo, HV_BINOP_MULTIPLY, 0, m, &cBinop_7YKfuKKo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aXq7e6Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ia0uQQoP, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ia0uQQoP_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Dox0tF5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eq2HNDXA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_T2E0QXBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VdvzjSfp, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_XP9J9EqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lLnVxQQV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9hEhXSZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9vUPJU0V, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QvvkYsqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BbmXqiC6, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pfQTvklY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tkrDbNw0_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_tkrDbNw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WpcWqiPZ, HV_BINOP_DIVIDE, 1, m, &cBinop_WpcWqiPZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r96KUojm_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_dKVW0AWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_iKRTiOAW_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_f1MacDnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_dKVW0AWg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iKRTiOAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WpcWqiPZ, HV_BINOP_DIVIDE, 0, m, &cBinop_WpcWqiPZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r96KUojm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f1MacDnn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WpcWqiPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Of454zAc, HV_BINOP_MULTIPLY, 1, m, &cBinop_Of454zAc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Of454zAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ImLOm9yn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wekhFQbp_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_OU8hodHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i3V9Mr0i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_LwVtwfxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yYYqJoB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yCwoTQtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_x3HyBhr3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x3HyBhr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Of454zAc, HV_BINOP_MULTIPLY, 0, m, &cBinop_Of454zAc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8ZGWneeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_pHvFZn0z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pHvFZn0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BxqCQgEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4vXmaGRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCJNtJYi, HV_BINOP_MULTIPLY, 1, m, &cBinop_fCJNtJYi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_jw2C1G63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ss7QubMF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ss7QubMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4vXmaGRb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MOzZ6kRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d99rom4n_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d99rom4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q25WUk4K, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q25WUk4K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yuj183PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BDsy9yM0, HV_BINOP_MULTIPLY, 1, m, &cBinop_BDsy9yM0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_trNZTGCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pj8KOjJc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pj8KOjJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yuj183PQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IMRNKVrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qynOx1u5, 1, m, &cVar_qynOx1u5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_htctJf9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5YkGRqKA, HV_BINOP_MULTIPLY, 1, m, &cBinop_5YkGRqKA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_IUE2kuvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bencSBMZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bencSBMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mp94svzR, HV_BINOP_MULTIPLY, 1, m, &cBinop_mp94svzR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_qynOx1u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p9nKKZme_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_cX8sZ4yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BfJshq0U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_yCwoTQtH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qOzkjiaq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_XSND9aXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8ZGWneeP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ImLOm9yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_OU8hodHh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wekhFQbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_LwVtwfxU_sendMessage);
}

void Heavy_WSTD_EQ::cSend_i3V9Mr0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jT9wvm6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yYYqJoB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ozaL4A03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_YPyEEgIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4ckukjVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_BxqCQgEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5TRP8ZRD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5TRP8ZRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXS7LAMZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_EXS7LAMZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EXS7LAMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZHPD6VoI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZHPD6VoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YPyEEgIt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_p9nKKZme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lsLhhJi4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lsLhhJi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YvJEcAfW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lgbmXgou_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4Mj4bTD7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OqZdDCGG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UUAii6v8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jU2cbeHA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fCJNtJYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dox0tF5W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Q25WUk4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T2E0QXBx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BDsy9yM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XP9J9EqM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5YkGRqKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9hEhXSZz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mp94svzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QvvkYsqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_k3B90GWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XSND9aXM, 1, m, &cVar_XSND9aXM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OsOwzLrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cX8sZ4yn, 0, m, &cVar_cX8sZ4yn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lgbmXgou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mp94svzR, HV_BINOP_MULTIPLY, 0, m, &cBinop_mp94svzR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OqZdDCGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BDsy9yM0, HV_BINOP_MULTIPLY, 0, m, &cBinop_BDsy9yM0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4Mj4bTD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5YkGRqKA, HV_BINOP_MULTIPLY, 0, m, &cBinop_5YkGRqKA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jU2cbeHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCJNtJYi, HV_BINOP_MULTIPLY, 0, m, &cBinop_fCJNtJYi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YvJEcAfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_UUAii6v8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q25WUk4K, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q25WUk4K_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qOzkjiaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qynOx1u5, 0, m, &cVar_qynOx1u5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BfJshq0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XSND9aXM, 0, m, &cVar_XSND9aXM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yihHXdDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4lPVwzP7, 1, m, &cIf_4lPVwzP7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fwuUvkTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bmW8vMSg, m);
}

void Heavy_WSTD_EQ::cBinop_Yxc36B2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fwuUvkTa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_crm90sAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4lPVwzP7, 0, m, &cIf_4lPVwzP7_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_6s72cQVA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TUPdDjhG, 0, m, &cSlice_TUPdDjhG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ABTNpW1m_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_TUPdDjhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EQIPRiNq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EQIPRiNq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_173G9x5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EQIPRiNq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_EQIPRiNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bNOHM4Sd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ny5DpWSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2LJ4KRr8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_6voDyJsz, 0, m, &cIf_6voDyJsz_sendMessage);
}

void Heavy_WSTD_EQ::cIf_6voDyJsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_be1pLn4s_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_fz5q30Jn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_1i8IdZ8W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_EZPunmIx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_nASqWNJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BU6Jtutg, HV_BINOP_POW, 0, m, &cBinop_BU6Jtutg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BU6Jtutg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wAHcje9b, 0, m, &cIf_wAHcje9b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AEGvbfAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fcZdg9aT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KdM0SUuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SUWmrST2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qgAsDxE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fz5q30Jn, 0, m, &cIf_fz5q30Jn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SUWmrST2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fz5q30Jn, 1, m, &cIf_fz5q30Jn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EZPunmIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_AEGvbfAP_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_1i8IdZ8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_wAHcje9b, 0, m, &cIf_wAHcje9b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fcZdg9aT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BU6Jtutg, HV_BINOP_POW, 1, m, &cBinop_BU6Jtutg_sendMessage);
  cMsg_nASqWNJm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_wAHcje9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_xRwMUyw5, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_2LJ4KRr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6voDyJsz, 1, m, &cIf_6voDyJsz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_be1pLn4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gqvcBk5f, HV_BINOP_GREATER_THAN, 1, m, &cBinop_gqvcBk5f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9BEElegF, HV_BINOP_EQ, 1, m, &cBinop_9BEElegF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Z68ruZX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TWsbiTJd, HV_BINOP_ADD, 0, m, &cBinop_TWsbiTJd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TWsbiTJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KdM0SUuZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qgAsDxE6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gqvcBk5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wAHcje9b, 1, m, &cIf_wAHcje9b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9BEElegF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2chxV3KR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_2chxV3KR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xRwMUyw5, m);
}

void Heavy_WSTD_EQ::cCast_8XJVNlhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ny5DpWSt, 0, m, &cVar_ny5DpWSt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0ygfGIR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z68ruZX5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_WXCVEy1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TWsbiTJd, HV_BINOP_ADD, 1, m, &cBinop_TWsbiTJd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gqvcBk5f, HV_BINOP_GREATER_THAN, 0, m, &cBinop_gqvcBk5f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9BEElegF, HV_BINOP_EQ, 0, m, &cBinop_9BEElegF_sendMessage);
}

void Heavy_WSTD_EQ::cVar_HAX8kXHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_856YjyPO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_f9KHJ9Rr, 0, m, &cIf_f9KHJ9Rr_sendMessage);
}

void Heavy_WSTD_EQ::cIf_f9KHJ9Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_atgqnZS1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_POYnw4LU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Iwlxwza7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_iMroaqno_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_pHipDLJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gbLdVK8N, HV_BINOP_POW, 0, m, &cBinop_gbLdVK8N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gbLdVK8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tmIZA0Rl, 0, m, &cIf_tmIZA0Rl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jzK0E8GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_B8Lk2Pqf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FMgeHqKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POYnw4LU, 0, m, &cIf_POYnw4LU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ShMz01Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rRat2mks_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rRat2mks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POYnw4LU, 1, m, &cIf_POYnw4LU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iMroaqno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_jzK0E8GT_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Iwlxwza7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tmIZA0Rl, 0, m, &cIf_tmIZA0Rl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_B8Lk2Pqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gbLdVK8N, HV_BINOP_POW, 1, m, &cBinop_gbLdVK8N_sendMessage);
  cMsg_pHipDLJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_tmIZA0Rl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mReWKW7Y_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fBCQn2fU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bJvedS1C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_856YjyPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f9KHJ9Rr, 1, m, &cIf_f9KHJ9Rr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_atgqnZS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WtgSBote, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WtgSBote_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NrxNt8oq, HV_BINOP_EQ, 1, m, &cBinop_NrxNt8oq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_AGPa5OZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIki3Rq2, HV_BINOP_ADD, 0, m, &cBinop_mIki3Rq2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mIki3Rq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ShMz01Fw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FMgeHqKt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WtgSBote_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tmIZA0Rl, 1, m, &cIf_tmIZA0Rl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NrxNt8oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yTxBpZiI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_yTxBpZiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mReWKW7Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fBCQn2fU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bJvedS1C_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mymG4Uug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HAX8kXHg, 0, m, &cVar_HAX8kXHg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9qBIDvL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AGPa5OZQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_PMNKirha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIki3Rq2, HV_BINOP_ADD, 1, m, &cBinop_mIki3Rq2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WtgSBote, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WtgSBote_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NrxNt8oq, HV_BINOP_EQ, 0, m, &cBinop_NrxNt8oq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_GQpuH5lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8NJ0Cfgu_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aDAnY0dV, 0, m, &cIf_aDAnY0dV_sendMessage);
}

void Heavy_WSTD_EQ::cIf_aDAnY0dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ClDEXb4Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_bWv2FKYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3LfrWplv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_nWZzT7BT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_UTLvwjqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3CNd9i8x, HV_BINOP_POW, 0, m, &cBinop_3CNd9i8x_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3CNd9i8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_22JKppjF, 0, m, &cIf_22JKppjF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IRGokDwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_WwaLg0GN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1TsAtOYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XM4F1R1i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WDAUmzwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bWv2FKYT, 0, m, &cIf_bWv2FKYT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XM4F1R1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bWv2FKYT, 1, m, &cIf_bWv2FKYT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nWZzT7BT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_IRGokDwv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3LfrWplv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_22JKppjF, 0, m, &cIf_22JKppjF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WwaLg0GN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3CNd9i8x, HV_BINOP_POW, 1, m, &cBinop_3CNd9i8x_sendMessage);
  cMsg_UTLvwjqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_22JKppjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_OdO1PBCu, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_8NJ0Cfgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aDAnY0dV, 1, m, &cIf_aDAnY0dV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ClDEXb4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3w6wJDGU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_3w6wJDGU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M4TJ850P, HV_BINOP_EQ, 1, m, &cBinop_M4TJ850P_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GjqBZmIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BzzOXkEE, HV_BINOP_ADD, 0, m, &cBinop_BzzOXkEE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BzzOXkEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1TsAtOYV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WDAUmzwL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3w6wJDGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_22JKppjF, 1, m, &cIf_22JKppjF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M4TJ850P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KXh7EvrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_KXh7EvrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OdO1PBCu, m);
}

void Heavy_WSTD_EQ::cCast_mKO9RuiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GQpuH5lo, 0, m, &cVar_GQpuH5lo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2WWVAPRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BzzOXkEE, HV_BINOP_ADD, 1, m, &cBinop_BzzOXkEE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3w6wJDGU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_3w6wJDGU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M4TJ850P, HV_BINOP_EQ, 0, m, &cBinop_M4TJ850P_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Zpnj2SI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GjqBZmIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_6aqs5mlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_xA1GIv2x, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_qcN2N700_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OUPyW3pF, 0, m, &cSlice_OUPyW3pF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EWi05YhI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_OUPyW3pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UYSX8QOq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UYSX8QOq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_N9peZyN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UYSX8QOq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UYSX8QOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rPGueocd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_EWi05YhI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4SbQZYr1, 0, m, &cSlice_4SbQZYr1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6s72cQVA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_4SbQZYr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hdp5clZh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hdp5clZh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_NBLhSu3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hdp5clZh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Hdp5clZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LQUqA32F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ABTNpW1m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ejDZkAhj, 0, m, &cSlice_ejDZkAhj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cfo3h2P0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ejDZkAhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GFOd5Gdf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GFOd5Gdf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_lfPfFldq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GFOd5Gdf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GFOd5Gdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sv13hkMp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_cfo3h2P0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dox3die0, 0, m, &cSlice_dox3die0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_dox3die0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MI8fu2S5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MI8fu2S5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_bkcubvPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MI8fu2S5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_MI8fu2S5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6lvLnBXR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_h8f1Gd8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2PK8jyMQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_x95ZdRUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5MuqLTp3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qLvl2hkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NL5TNX37, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_6hCi9gOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rUacWcFK, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Nj4zTF0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vu0SIyNh, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hLNtEOpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w6EZ39aI_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_w6EZ39aI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OM6xdzXt, HV_BINOP_DIVIDE, 1, m, &cBinop_OM6xdzXt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RQBpCIrl_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_4QGYX91s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oGNwd7Qc_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_inZLZcp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_4QGYX91s_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oGNwd7Qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OM6xdzXt, HV_BINOP_DIVIDE, 0, m, &cBinop_OM6xdzXt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RQBpCIrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_inZLZcp6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OM6xdzXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSPpxs9H, HV_BINOP_MULTIPLY, 1, m, &cBinop_qSPpxs9H_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qSPpxs9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l2qGP0FA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5erDXdq9_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_WYbOG0VU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VGagSW3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_cdKtm3FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PkLwRMtq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IEIImgtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_rjh9u6Jd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rjh9u6Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSPpxs9H, HV_BINOP_MULTIPLY, 0, m, &cBinop_qSPpxs9H_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jSpgFOcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_d1bqGtPz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d1bqGtPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ImU77Qmk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4y2S2WmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MTcG9YH7, 1, m, &cVar_MTcG9YH7_sendMessage);
}

void Heavy_WSTD_EQ::cVar_MTcG9YH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1fqSxrEs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_U7ERDbNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XhrTBmYy, HV_BINOP_MULTIPLY, 1, m, &cBinop_XhrTBmYy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qhcGa9rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_U7ERDbNQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yOxL9ZmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zSndtFQH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zSndtFQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d4B2pMJj, HV_BINOP_MULTIPLY, 1, m, &cBinop_d4B2pMJj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g5KpXmud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FV6gJOpK, HV_BINOP_MULTIPLY, 1, m, &cBinop_FV6gJOpK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MFr90wd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_g5KpXmud_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zWiVTQK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yDq9oEva, HV_BINOP_MULTIPLY, 1, m, &cBinop_yDq9oEva_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_iRcw4dQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5UmNm4XJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5UmNm4XJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8fd0Mnr, HV_BINOP_MULTIPLY, 1, m, &cBinop_H8fd0Mnr_sendMessage);
}

void Heavy_WSTD_EQ::cVar_6hI2lQDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iNTKcJXl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IEIImgtl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9lIjBjJ1_sendMessage);
}

void Heavy_WSTD_EQ::cVar_EhZTmi8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_jSpgFOcE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_l2qGP0FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_WYbOG0VU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5erDXdq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_cdKtm3FJ_sendMessage);
}

void Heavy_WSTD_EQ::cSend_VGagSW3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_btlcaW8t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_PkLwRMtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0EcDVfCC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_a69wGZKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OJnyVr2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ImU77Qmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RYz7Ot4O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RYz7Ot4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_97dubFYQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_97dubFYQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_97dubFYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ykFiFq6S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ykFiFq6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a69wGZKn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_1fqSxrEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uxPL1BnG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uxPL1BnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LA5vnVya_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TFQ1ZnOV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oJZvCEUl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EWZOGgCr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mzFxYNgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wz8YmxtP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XhrTBmYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h8f1Gd8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_d4B2pMJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x95ZdRUR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FV6gJOpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qLvl2hkL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yDq9oEva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6hCi9gOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_H8fd0Mnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nj4zTF0H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_DWKvmkc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EhZTmi8A, 1, m, &cVar_EhZTmi8A_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7igHkh8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6hI2lQDI, 0, m, &cVar_6hI2lQDI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LA5vnVya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_EWZOGgCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FV6gJOpK, HV_BINOP_MULTIPLY, 0, m, &cBinop_FV6gJOpK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oJZvCEUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yDq9oEva, HV_BINOP_MULTIPLY, 0, m, &cBinop_yDq9oEva_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TFQ1ZnOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8fd0Mnr, HV_BINOP_MULTIPLY, 0, m, &cBinop_H8fd0Mnr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mzFxYNgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d4B2pMJj, HV_BINOP_MULTIPLY, 0, m, &cBinop_d4B2pMJj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wz8YmxtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XhrTBmYy, HV_BINOP_MULTIPLY, 0, m, &cBinop_XhrTBmYy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9lIjBjJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MTcG9YH7, 0, m, &cVar_MTcG9YH7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iNTKcJXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EhZTmi8A, 0, m, &cVar_EhZTmi8A_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_o2itpKAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_84yPUZHU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ZgcA0ltK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5kawRpkU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fmz6C1fZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L0fV7bpK, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QHDaNneq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c6pni4SS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bUHWtvY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HznJpTCi_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_HznJpTCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d425dd0B, HV_BINOP_DIVIDE, 1, m, &cBinop_d425dd0B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YqUk34Vz_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_LyAzZFXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VAcRxxmL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bT0r0tW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_LyAzZFXA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VAcRxxmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d425dd0B, HV_BINOP_DIVIDE, 0, m, &cBinop_d425dd0B_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YqUk34Vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bT0r0tW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_d425dd0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WZUautW2, HV_BINOP_MULTIPLY, 1, m, &cBinop_WZUautW2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WZUautW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QlL0vqVV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HbemS6Mw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_b2PuLlgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q5DUi8f3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_PfdkmUGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t5aVFwUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_eG61O2zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_YuN1hMOw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YuN1hMOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WZUautW2, HV_BINOP_MULTIPLY, 0, m, &cBinop_WZUautW2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F1a4gClF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_CFe1vr01_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CFe1vr01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D7bqnh39_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jAuEtkkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0o4SWa2E, HV_BINOP_MULTIPLY, 1, m, &cBinop_0o4SWa2E_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fBqymIcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WaiWwADz, 1, m, &cVar_WaiWwADz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a6gja8xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tzhc2NDm, HV_BINOP_MULTIPLY, 1, m, &cBinop_tzhc2NDm_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Rwaf8cHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cXFbSrB8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cXFbSrB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hDW430tv, HV_BINOP_MULTIPLY, 1, m, &cBinop_hDW430tv_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WaiWwADz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xeOQrNvE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Jau0kv9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZeF1CuVq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_eG61O2zb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KzQR6V72_sendMessage);
}

void Heavy_WSTD_EQ::cVar_QCuUXi2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_F1a4gClF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HbemS6Mw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PfdkmUGj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QlL0vqVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_b2PuLlgN_sendMessage);
}

void Heavy_WSTD_EQ::cSend_q5DUi8f3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rpSKUABm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_t5aVFwUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ILbhYYGM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_c8CPEGBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ubtl3rQm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_D7bqnh39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8b4SUqxr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8b4SUqxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QTtEMyOP, HV_BINOP_MULTIPLY, 1, m, &cBinop_QTtEMyOP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QTtEMyOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zj7vw8YM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zj7vw8YM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c8CPEGBw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xeOQrNvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PXFX1tni_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PXFX1tni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WfcLVitJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_84DJZMtS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WevPKAAq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z8HOqDn8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yrODM9FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o2itpKAf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_0o4SWa2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZgcA0ltK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tzhc2NDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fmz6C1fZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hDW430tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QHDaNneq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_JWHB774W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jau0kv9Y, 0, m, &cVar_Jau0kv9Y_sendMessage);
}

void Heavy_WSTD_EQ::cCast_L9vqfINc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QCuUXi2s, 1, m, &cVar_QCuUXi2s_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KzQR6V72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WaiWwADz, 0, m, &cVar_WaiWwADz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZeF1CuVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QCuUXi2s, 0, m, &cVar_QCuUXi2s_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WfcLVitJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hDW430tv, HV_BINOP_MULTIPLY, 0, m, &cBinop_hDW430tv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_84DJZMtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tzhc2NDm, HV_BINOP_MULTIPLY, 0, m, &cBinop_tzhc2NDm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WevPKAAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0o4SWa2E, HV_BINOP_MULTIPLY, 0, m, &cBinop_0o4SWa2E_sendMessage);
}

void Heavy_WSTD_EQ::cCast_z8HOqDn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrODM9FU, HV_BINOP_MULTIPLY, 0, m, &cBinop_yrODM9FU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FoKQSddd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qaakaDaQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ZXvk3y75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qkv5ta5R, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_l6j52DpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RmvUjBDT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jGpPFz1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v2am3THf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_m6lc8l9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TFszBrdR, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Hr2T3g9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iQFBTAPO_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_iQFBTAPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6IYWwzc, HV_BINOP_DIVIDE, 1, m, &cBinop_M6IYWwzc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hy89eAU3_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_MmcseBHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KDlwL7oe_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_qzcytrqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MmcseBHe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KDlwL7oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M6IYWwzc, HV_BINOP_DIVIDE, 0, m, &cBinop_M6IYWwzc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hy89eAU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qzcytrqf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_M6IYWwzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kc6VPz86, HV_BINOP_MULTIPLY, 1, m, &cBinop_Kc6VPz86_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Kc6VPz86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rTe42oyU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NgYArD7K_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_5tE6ftqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aueZgy0A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_zSwJPQIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NuzEVbAy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_D7vT4oqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2mk5Vleu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2mk5Vleu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kc6VPz86, HV_BINOP_MULTIPLY, 0, m, &cBinop_Kc6VPz86_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x0JBzFoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_fZpcqe9K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fZpcqe9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2KiHdpBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TX7Nqucr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QxZMvCS2, HV_BINOP_MULTIPLY, 1, m, &cBinop_QxZMvCS2_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EtTswrWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v604g5xw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v604g5xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TX7Nqucr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mtlN8wGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7NYpTc5F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7NYpTc5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yBwNZPOJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_yBwNZPOJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QQReDVo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3Nod9cL, HV_BINOP_MULTIPLY, 1, m, &cBinop_A3Nod9cL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XqtQrEEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_F04ZYsvk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F04ZYsvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QQReDVo3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3OsKPC9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NaDNOKJZ, 1, m, &cVar_NaDNOKJZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tw4Do639_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dSINX0JX, HV_BINOP_MULTIPLY, 1, m, &cBinop_dSINX0JX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_jRLvtj4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sPl8X5iY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sPl8X5iY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DbnkiVK9, HV_BINOP_MULTIPLY, 1, m, &cBinop_DbnkiVK9_sendMessage);
}

void Heavy_WSTD_EQ::cVar_NaDNOKJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uEdrhh5B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_iXCyTSvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1df66Wnp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_D7vT4oqa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O1JFEmjh_sendMessage);
}

void Heavy_WSTD_EQ::cVar_y7enKTP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_x0JBzFoP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rTe42oyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5tE6ftqG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NgYArD7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zSwJPQIk_sendMessage);
}

void Heavy_WSTD_EQ::cSend_aueZgy0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6GcyHjQX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NuzEVbAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qbIJ8IFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ERkdBS3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gSxtFKuQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_2KiHdpBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ut0PZbmI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ut0PZbmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QZaZTOV6, HV_BINOP_MULTIPLY, 1, m, &cBinop_QZaZTOV6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QZaZTOV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ymhfqh7B_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ymhfqh7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ERkdBS3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_uEdrhh5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mnOspg8z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mnOspg8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oTPbCEFq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FKrtuZng_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DW85qu8U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jAPQwNsM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ufJmjpjl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1OxcOhem_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QxZMvCS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FoKQSddd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yBwNZPOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZXvk3y75_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_A3Nod9cL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l6j52DpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dSINX0JX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jGpPFz1l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DbnkiVK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m6lc8l9x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_HTT0k1iD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iXCyTSvf, 0, m, &cVar_iXCyTSvf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DfJOZ6gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y7enKTP2, 1, m, &cVar_y7enKTP2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oTPbCEFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_FKrtuZng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DbnkiVK9, HV_BINOP_MULTIPLY, 0, m, &cBinop_DbnkiVK9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1OxcOhem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QxZMvCS2, HV_BINOP_MULTIPLY, 0, m, &cBinop_QxZMvCS2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ufJmjpjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yBwNZPOJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_yBwNZPOJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jAPQwNsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3Nod9cL, HV_BINOP_MULTIPLY, 0, m, &cBinop_A3Nod9cL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DW85qu8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dSINX0JX, HV_BINOP_MULTIPLY, 0, m, &cBinop_dSINX0JX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1df66Wnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y7enKTP2, 0, m, &cVar_y7enKTP2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O1JFEmjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NaDNOKJZ, 0, m, &cVar_NaDNOKJZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mReWKW7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6aqs5mlF, 1, m, &cIf_6aqs5mlF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JjoLgbAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xA1GIv2x, m);
}

void Heavy_WSTD_EQ::cBinop_fBCQn2fU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JjoLgbAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bJvedS1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6aqs5mlF, 0, m, &cIf_6aqs5mlF_sendMessage);
}

void Heavy_WSTD_EQ::cVar_D5clmys9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1Z48g3j, HV_BINOP_DIVIDE, 0, m, &cBinop_I1Z48g3j_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Yn3DRUSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8YnTwanS, HV_BINOP_DIVIDE, 1, m, &cBinop_8YnTwanS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1Z48g3j, HV_BINOP_DIVIDE, 1, m, &cBinop_I1Z48g3j_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_SxRpcLOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HpG7Eh7L, HV_BINOP_DIVIDE, 0, m, &cBinop_HpG7Eh7L_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_MkQmCwF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HpG7Eh7L, HV_BINOP_DIVIDE, 1, m, &cBinop_HpG7Eh7L_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5HarTTJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8YnTwanS, HV_BINOP_DIVIDE, 0, m, &cBinop_8YnTwanS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o7fchvbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D5clmys9, 0, m, &cVar_D5clmys9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7tfggHwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yn3DRUSv, 0, m, &cVar_Yn3DRUSv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8YnTwanS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_SxRpcLOK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_I1Z48g3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_MkQmCwF6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HpG7Eh7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_eUNpnAmx_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Fo2z3DrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_M0hMoAS8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KW6wKHz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_xpKObm8D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eUNpnAmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KW6wKHz4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xpKObm8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Fo2z3DrI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M0hMoAS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UOLs8sru_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_s0m4kn4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SdGUgDK9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qcN2N700_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LOFkR6uJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SdGUgDK9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qcN2N700_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_OhQCXyVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SdGUgDK9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qcN2N700_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_D6Ljhtd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SdGUgDK9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qcN2N700_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UOLs8sru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SdGUgDK9_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qcN2N700_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Di0sHYP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HgM0N5Kk, 0, m, &cVar_HgM0N5Kk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mAnNRUvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_H6vLgg9j, 0, m, &cVar_H6vLgg9j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MV5LLL1Q, 0, m, &cVar_MV5LLL1Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0uMDkVNu, 0, m, &cVar_0uMDkVNu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rNITCFaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H6vLgg9j, 0, m, &cVar_H6vLgg9j_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_8iDf9ghe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MV5LLL1Q, 0, m, &cVar_MV5LLL1Q_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_P76kGqUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0uMDkVNu, 0, m, &cVar_0uMDkVNu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_McALSAaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D7E78vAs, 0, m, &cVar_D7E78vAs_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9F5XxH29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PvGIiQPa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HHIk9CIf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_d1gHa02S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nnd0zuIa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lw2cp81p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ebklagCj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ekNVqVCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u8aBZHEz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V2ggJQUi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uuuPFwdL_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ptUgfZMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l3JNgsVV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jEoMSeOk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1uC7Xty8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_euLqAamA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_teC1x0NZ_sendMessage(_c, 0, m);
  cMsg_uId7lTnf_sendMessage(_c, 0, m);
  cMsg_pfQTvklY_sendMessage(_c, 0, m);
  cMsg_hLNtEOpt_sendMessage(_c, 0, m);
  cMsg_bUHWtvY6_sendMessage(_c, 0, m);
  cMsg_Hr2T3g9D_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lurXnupj, 0, m, &cVar_lurXnupj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D7E78vAs, 0, m, &cVar_D7E78vAs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cX8sZ4yn, 0, m, &cVar_cX8sZ4yn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6hI2lQDI, 0, m, &cVar_6hI2lQDI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jau0kv9Y, 0, m, &cVar_Jau0kv9Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iXCyTSvf, 0, m, &cVar_iXCyTSvf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H9onsVOh, 0, m, &cVar_H9onsVOh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wvRaefjx, 0, m, &cVar_wvRaefjx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RO9EHkPj, 0, m, &cVar_RO9EHkPj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sb0wBEqm, 0, m, &cVar_Sb0wBEqm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VS3yf615, 0, m, &cVar_VS3yf615_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_01byo3fo, 0, m, &cVar_01byo3fo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6CIUOA37, 0, m, &cVar_6CIUOA37_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tavRIZer, 0, m, &cVar_tavRIZer_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_173G9x5O, 0, m, &cVar_173G9x5O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ny5DpWSt, 0, m, &cVar_ny5DpWSt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HAX8kXHg, 0, m, &cVar_HAX8kXHg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GQpuH5lo, 0, m, &cVar_GQpuH5lo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N9peZyN5, 0, m, &cVar_N9peZyN5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NBLhSu3o, 0, m, &cVar_NBLhSu3o_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lfPfFldq, 0, m, &cVar_lfPfFldq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bkcubvPH, 0, m, &cVar_bkcubvPH_sendMessage);
  cMsg_mAnNRUvG_sendMessage(_c, 0, m);
  cMsg_Di0sHYP1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_c05wVMdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jz5KUuAf, HV_BINOP_MULTIPLY, 0, m, &cBinop_jz5KUuAf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_r4fNrldN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZoKNuS4E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Hf7YCvui_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ip2VllZM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_efljQA6g_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_waekoRAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WEgyCkzU_sendMessage);
  cMsg_zFhDpmZo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_k9lK26Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_86q6EaXb, HV_BINOP_MULTIPLY, 0, m, &cBinop_86q6EaXb_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_OkiJDTyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_XwCtH8Y0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_oHuneJY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7YKfuKKo, HV_BINOP_MULTIPLY, 1, m, &cBinop_7YKfuKKo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aDFm7uQH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YM0PgGPt_sendMessage);
  cMsg_VvAgeT1v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_jT9wvm6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXS7LAMZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_EXS7LAMZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ozaL4A03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jw2C1G63_sendMessage(_c, 0, m);
  cMsg_MOzZ6kRf_sendMessage(_c, 0, m);
  cMsg_trNZTGCT_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_htctJf9A_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_4ckukjVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IMRNKVrn_sendMessage);
  cMsg_IUE2kuvS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_bNOHM4Sd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jau0kv9Y, 0, m, &cVar_Jau0kv9Y_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6lvLnBXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L9vqfINc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JWHB774W_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rPGueocd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8XJVNlhr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WXCVEy1a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ygfGIR5_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sv13hkMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKO9RuiY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2WWVAPRl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zpnj2SI3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_LQUqA32F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mymG4Uug_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PMNKirha_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9qBIDvL0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_btlcaW8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_97dubFYQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_97dubFYQ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0EcDVfCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qhcGa9rj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yOxL9ZmJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MFr90wd1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zWiVTQK8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_OJnyVr2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4y2S2WmD_sendMessage);
  cMsg_iRcw4dQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_rpSKUABm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QTtEMyOP, HV_BINOP_MULTIPLY, 0, m, &cBinop_QTtEMyOP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ILbhYYGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_a6gja8xz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ubtl3rQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrODM9FU, HV_BINOP_MULTIPLY, 1, m, &cBinop_yrODM9FU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jAuEtkkb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fBqymIcL_sendMessage);
  cMsg_Rwaf8cHE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_6GcyHjQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QZaZTOV6, HV_BINOP_MULTIPLY, 0, m, &cBinop_QZaZTOV6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qbIJ8IFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EtTswrWg_sendMessage(_c, 0, m);
  cMsg_mtlN8wGr_sendMessage(_c, 0, m);
  cMsg_XqtQrEEp_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tw4Do639_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gSxtFKuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3OsKPC9P_sendMessage);
  cMsg_jRLvtj4n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_R968yQPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HgM0N5Kk, 0, m, &cVar_HgM0N5Kk_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_or1coXb9, VOf(Bf0));
    __hv_varread_f(&sVarf_JJoK4Ns8, VOf(Bf1));
    __hv_varread_f(&sVarf_pW8pfcbD, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_0mTINLCR, VOf(Bf0));
    __hv_varread_f(&sVarf_ZVcWQjET, VOf(Bf1));
    __hv_varread_f(&sVarf_cr0EqZOt, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_vTLkNvUp, VOf(Bf0));
    __hv_line_f(&sLine_qdx6aReO, VOf(Bf1));
    __hv_line_f(&sLine_XzYDv7R6, VOf(Bf4));
    __hv_line_f(&sLine_MQolr9at, VOf(Bf5));
    __hv_line_f(&sLine_geTh6lvG, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_glyMaCqs, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_w5iAgm9F, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_uB5vbDQb, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_izFUuA9c, VOf(Bf1));
    __hv_line_f(&sLine_kEO1bAAX, VOf(Bf0));
    __hv_line_f(&sLine_Q93Tseen, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_IAFO4QD0, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_bmW8vMSg, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_eq2HNDXA, VOf(Bf7));
    __hv_line_f(&sLine_VdvzjSfp, VOf(Bf1));
    __hv_line_f(&sLine_lLnVxQQV, VOf(Bf4));
    __hv_line_f(&sLine_9vUPJU0V, VOf(Bf6));
    __hv_line_f(&sLine_BbmXqiC6, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_fOTtrF5U, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Jnw6v0v1, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_or1coXb9, VIf(Bf5));
    __hv_varwrite_f(&sVarf_JJoK4Ns8, VIf(Bf0));
    __hv_varwrite_f(&sVarf_pW8pfcbD, VIf(Bf6));
    __hv_line_f(&sLine_2PK8jyMQ, VOf(Bf6));
    __hv_line_f(&sLine_5MuqLTp3, VOf(Bf0));
    __hv_line_f(&sLine_NL5TNX37, VOf(Bf5));
    __hv_line_f(&sLine_rUacWcFK, VOf(Bf8));
    __hv_line_f(&sLine_Vu0SIyNh, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_4jEQiCQ3, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_xRwMUyw5, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_84yPUZHU, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_5kawRpkU, VOf(Bf0));
    __hv_line_f(&sLine_L0fV7bpK, VOf(Bf6));
    __hv_line_f(&sLine_c6pni4SS, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_MPWoMkVx, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_xA1GIv2x, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_qaakaDaQ, VOf(Bf1));
    __hv_line_f(&sLine_qkv5ta5R, VOf(Bf0));
    __hv_line_f(&sLine_RmvUjBDT, VOf(Bf5));
    __hv_line_f(&sLine_v2am3THf, VOf(Bf4));
    __hv_line_f(&sLine_TFszBrdR, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_fNFJeLtm, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_OdO1PBCu, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_0mTINLCR, VIf(Bf8));
    __hv_varwrite_f(&sVarf_ZVcWQjET, VIf(Bf6));
    __hv_varwrite_f(&sVarf_cr0EqZOt, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
